@@ -681,7 +681,7 @@ bool DatabaseManager::insertTarget(Target* target)
 	return ret;
 }
 
-QList<Target*> DatabaseManager::getTargets(QString filter)
+QList<Target*> DatabaseManager::getTargets(const QString & filter)
 {
 	QList<Target*> result;
 
