@@ -37,7 +37,7 @@ protected:
     }
 };
 
-DetailWindow::DetailWindow(Target * _target, bool istemplate, bool edit, eWallet *paTarget, QWidget *parent) :
+DetailWindow::DetailWindow(Target * _target, const QString & groupName, bool istemplate, bool edit, eWallet *paTarget, QWidget *parent) :
 		QMainWindow(parent)
 {
 	this->setAttribute(Qt::WA_Maemo5StackedWindow);
@@ -50,6 +50,8 @@ DetailWindow::DetailWindow(Target * _target, bool istemplate, bool edit, eWallet
 	this->parent = paTarget;
 	this->edit = edit;
 
+	qDebug () << "DETAIL " << target << " " << groupName << " " << istemplate << " " << edit;
+
 	if (istemplate) {
 		this->target = new Target ();
 		this->target->type = _target->type;
@@ -70,7 +72,8 @@ DetailWindow::DetailWindow(Target * _target, bool istemplate, bool edit, eWallet
 	else
 	if (isNew) {
 		this->target = new Target ();
-		this->target->type = this->parent->types[0];
+		this->target->groupName = groupName;
+		this->target->type = this->parent->types->at(0);
 		changeFields (0);
 	}
 
@@ -168,16 +171,16 @@ DetailWindow::DetailWindow(Target * _target, bool istemplate, bool edit, eWallet
 		typeLineEdit = new QComboBox(this);
 
 		bool selected = false;
-		for(int i = 0; i < this->parent->types.size(); i++) {
-			typeLineEdit->addItem (this->parent->types[i], this->parent->types[i]);
+		for(int i = 0; i < this->parent->types->size(); i++) {
+			typeLineEdit->addItem (this->parent->types->at(i), this->parent->types->at(i));
 
-				if (this->target->type == this->parent->types[i]) {
+				if (this->target->type == this->parent->types->at(i)) {
 					typeLineEdit->setCurrentIndex(i);
 					selected = true;
 				}
 		}
 		if (!selected) {
-			typeLineEdit->setCurrentIndex(this->parent->types.size() - 1);
+			typeLineEdit->setCurrentIndex(this->parent->types->size() - 1);
 		}
 
 	    connect(typeLineEdit, SIGNAL(activated(int)), this, SLOT(emitCommitData(int)));
@@ -323,24 +326,39 @@ void DetailWindow::_addField (TargetField * field) {
 
 	if (field->type == TYPE_TEXT) {
 		QTextEdit * nameLineEdit = new QTextEdit(this);
-		//nameLineEdit->setContextMenuPolicy(Qt::NoContextMenu);
 		componentLayout->addWidget(nameLineEdit, pos + 1, 3, s, 4);
-		//nameLineEdit->setCompleter(NULL);
-
 		nameLineEdit->setText (field->value);
 		this->values.append (nameLineEdit);
 		//nameLineEdit->setUserData(0,info);
 	}
-/*	else
-	if (field->type == TYPE_PHONE_NUMBER) {
-		// TODO
+	else
+	if (field->type == TYPE_PASSWORD) {
 		QLineEdit * nameLineEdit = new QLineEdit(this);
-		//nameLineEdit->setContextMenuPolicy(Qt::NoContextMenu);
 		componentLayout->addWidget(nameLineEdit, pos + 1, 3, s, 4);
 		nameLineEdit->setText (field->value);
+		//nameLineEdit->setInputMask (">")
+		this->values.append (nameLineEdit);
+		//nameLineEdit->setUserData(0,info);
+	}
+	else
+	if (field->type == TYPE_DATE) {
+		QLineEdit * nameLineEdit = new QLineEdit(this);
+		componentLayout->addWidget(nameLineEdit, pos + 1, 3, s, 4);
+		nameLineEdit->setText (field->value);
+		nameLineEdit->setInputMask ("00-00-0000");
+		nameLineEdit->setToolTip("format dd-mm-yyyy");
+		this->values.append (nameLineEdit);
+		//nameLineEdit->setUserData(0,info);
+	}
+	else
+	if (field->type == TYPE_PHONE_NUMBER) {
+		QLineEdit * nameLineEdit = new QLineEdit(this);
+		componentLayout->addWidget(nameLineEdit, pos + 1, 3, s, 4);
+		nameLineEdit->setText (field->value);
+		nameLineEdit->setInputMask ("00000000000");
 		this->values.append (nameLineEdit);
 
-	}*/
+	}
 	else {
 		QLineEdit * nameLineEdit = new QLineEdit(this);
 		nameLineEdit->setCompleter(NULL);
@@ -353,6 +371,7 @@ void DetailWindow::_addField (TargetField * field) {
 		//nameLineEdit->setUserData(0,info);
 	}
 
+	//qDebug () << "SHOWN " << field->name << " v=" << field->value << " t=" << field->type;
 }
 
 void DetailWindow::showFields () {
@@ -463,8 +482,8 @@ void DetailWindow::changeFields (int a) {
 			qDebug () << "keep" << field->name;
 	}
 
-	for (int i = 0; i < parent->fieldsByType [a]->size(); i++) {
-		TargetField tmp = parent->fieldsByType [a]->at(i);
+	for (int i = 0; i < parent->fieldsByType->at (a)->size(); i++) {
+		TargetField tmp = parent->fieldsByType->at (a)->at(i);
 
 		if (!target->existField (tmp.name)) {
 			TargetField * f;
@@ -526,11 +545,11 @@ void DetailWindow::saveTarget () {
 		
 		field->name = labels[i]->text();
 		if (field->type == TYPE_TEXT) {
-			//qDebug () << "getting TEX field " << i;
+			qDebug () << "getting TEX field " << i;
 			field->value = ((QTextEdit*)values[i])->toPlainText();
 		}
 		else {
-			//qDebug () << "getting LIN field " << i;
+			qDebug () << "getting LIN field " << i;
 			field->value = ((QLineEdit*)values[i])->text();
 		}
 	}
