@@ -49,7 +49,7 @@ class DetailWindow: public QMainWindow
 	Q_OBJECT
 
 public:
-	DetailWindow (Target * target, bool istemplate, bool edit, eWallet *paTarget, QWidget *parent = 0);
+	DetailWindow (Target * target, const QString & groupName, bool istemplate, bool edit, eWallet *paTarget, QWidget *parent = 0);
 	~DetailWindow ();
 	
 	void addField (TargetField * field);
