@@ -36,8 +36,31 @@
 
 DatabaseManager * dbManager;
 
+eWallet::eWallet(QString group, eWallet * _parent, QWidget *parent) : QMainWindow(parent)
+{
+	types = _parent->types;
+	fieldsByType = _parent->fieldsByType;
+
+	centralWidget = NULL;
+	currentGroup = group;
+
+	this->setAttribute(Qt::WA_Maemo5AutoOrientation, true);
+	//connect(QApplication::desktop(), SIGNAL(resized(int)), this, SLOT(orientationChanged(int)));
+
+	this->setAttribute(Qt::WA_Maemo5StackedWindow);
+
+	ascSort = true;
+	currentFilter = "";
+
+	isShowGroups = 2;
+
+	showList ();
+	showTargets(true, currentGroup);
+}
+
 eWallet::eWallet(QWidget *parent) : QMainWindow(parent)
 {
+	currentGroup = "";
 	centralWidget = NULL;
 	isShowGroups = 0;
 
@@ -49,10 +72,6 @@ eWallet::eWallet(QWidget *parent) : QMainWindow(parent)
 	ascSort = true;
 	currentFilter = "";
 
-	grabGesture(Qt::SwipeGesture);
-
-	//this->setAttribute(Qt::WA_Maemo5AutoOrientation, true);
-
 	loadTypesAndFields ();
 
 	::dbManager = new DatabaseManager(this);
@@ -75,49 +94,59 @@ void eWallet::showList () {
 	isAskPassword = false;
 
 	setProperty("FingerScrollable", false);
-	//setContextMenuPolicy(Qt::NoContextMenu);
-	//                         // Central widget and Layout
-	//if (centralWidget == NULL) {
-		centralWidget = new QWidget(this);
+	centralWidget = new QWidget(this);
+	//centralWidget->grabGesture(Qt::SwipeGesture);
 
-		setContextMenuPolicy(Qt::DefaultContextMenu);
-	//	centralWidget->setContextMenuPolicy(Qt::DefaultContextMenu);
+//		grabGesture(Qt::PanGesture);
+//		grabGesture(Qt::PinchGesture);
+//	    grabGesture(Qt::SwipeGesture);
 
-		vboxlayout = new QVBoxLayout;
-		vboxlayout->setSpacing(0);
-		vboxlayout->setMargin(0);
-		// Custom list box
 
-		fnListWidget = new QListWidget(this);
-		fnListWidget->setSortingEnabled(false);
-		fnListWidget->setFocusPolicy(Qt::NoFocus);
-		vboxlayout->addWidget(fnListWidget);
+	//backButton = new QPushButton("<< Back", this);
 
-		QObject::connect(fnListWidget, SIGNAL(itemClicked(QListWidgetItem *)), this, SLOT(selectItem(QListWidgetItem *)));
-		QObject::connect(fnListWidget, SIGNAL(itemDoubleClicked(QListWidgetItem *)), this, SLOT(selectDItem(QListWidgetItem *)));
+	setContextMenuPolicy(Qt::DefaultContextMenu);
+//	centralWidget->setContextMenuPolicy(Qt::DefaultContextMenu);
 
-		inputWidget = new QHBoxLayout;
-		inputWidget->setContentsMargins(2, 2, 2, 0);
-		vboxlayout->addLayout(inputWidget);
+	vboxlayout = new QVBoxLayout;
+	vboxlayout->setSpacing(0);
+	vboxlayout->setMargin(0);
+	// Custom list box
+	//vboxlayout->addWidget(backButton);
 
-		cancelSearch = new QPushButton(QIcon(":/resources/icon_clear.png"), "", this);
-		searchField = new QLineEdit ();
-		hideSearch = new QPushButton(QIcon(":/resources/icon_hide.png"), "", this);
+	fnListWidget = new QListWidget(this);
+	fnListWidget->setSortingEnabled(false);
+	fnListWidget->setFocusPolicy(Qt::NoFocus);
+	vboxlayout->addWidget(fnListWidget);
 
-		inputWidget->addWidget(cancelSearch);
-		inputWidget->addWidget(searchField);
-		inputWidget->addWidget(hideSearch);
+	//fnListWidget->grabGesture(Qt::SwipeGesture);
 
-		QObject::connect(cancelSearch, SIGNAL(clicked()), this, SLOT(_cancelSearch()));
-		QObject::connect(hideSearch, SIGNAL(clicked()), this, SLOT(_hideSearch()));
-		QObject::connect(searchField, SIGNAL(textChanged(const QString &)), this, SLOT(textChanged(const QString &)));
+	QObject::connect(fnListWidget, SIGNAL(itemClicked(QListWidgetItem *)), this, SLOT(selectItem(QListWidgetItem *)));
+	QObject::connect(fnListWidget, SIGNAL(itemDoubleClicked(QListWidgetItem *)), this, SLOT(selectDItem(QListWidgetItem *)));
 
-		cancelSearch->hide ();
-		searchField->hide ();
-		hideSearch->hide ();
+	inputWidget = new QHBoxLayout;
+	inputWidget->setContentsMargins(2, 2, 2, 0);
+	vboxlayout->addLayout(inputWidget);
 
-		centralWidget->setLayout(vboxlayout);
-	//}
+	cancelSearch = new QPushButton(QIcon(":/resources/icon_clear.png"), "", this);
+	searchField = new QLineEdit ();
+	hideSearch = new QPushButton(QIcon(":/resources/icon_hide.png"), "", this);
+
+	inputWidget->addWidget(cancelSearch);
+	inputWidget->addWidget(searchField);
+	inputWidget->addWidget(hideSearch);
+
+	//QObject::connect(backButton, SIGNAL(clicked()), this, SLOT(_clickBack()));
+	//backButton->hide ();
+
+	QObject::connect(cancelSearch, SIGNAL(clicked()), this, SLOT(_cancelSearch()));
+	QObject::connect(hideSearch, SIGNAL(clicked()), this, SLOT(_hideSearch()));
+	QObject::connect(searchField, SIGNAL(textChanged(const QString &)), this, SLOT(textChanged(const QString &)));
+
+	cancelSearch->hide ();
+	searchField->hide ();
+	hideSearch->hide ();
+
+	centralWidget->setLayout(vboxlayout);
 
 	createMenu ();
 
@@ -126,49 +155,55 @@ void eWallet::showList () {
 
 	qDebug () << "setFocus()";
 	centralWidget->setFocus ();
-
-	showInfo (true);
 }
 
+void eWallet::_clickBack () {
+	isShowGroups = (isShowGroups) % 2 + 1;
+	_cancelSearch ();
+	showInfo(true);
+}
 void eWallet::changeMode () {
 	isShowGroups = (isShowGroups) % 2 + 1;
 	_cancelSearch ();
 	showInfo(true);
 }
 
-void eWallet::swipeTriggered(QSwipeGesture *gesture) {
-	if (gesture->state() == Qt::GestureFinished) {
-		if (gesture->horizontalDirection() == QSwipeGesture::Left
-			|| gesture->verticalDirection() == QSwipeGesture::Up)
-			isShowGroups = (isShowGroups + 1) % 2 + 1;
-		else
-			isShowGroups = (isShowGroups + 1) % 2 + 1;
-		showInfo(false);
-	}
-}
-
-bool eWallet::gestureEvent(QGestureEvent *event) {
-    if (QGesture *swipe = event->gesture(Qt::SwipeGesture))
-        swipeTriggered(static_cast<QSwipeGesture *>(swipe));
-//    else if (QGesture *pan = event->gesture(Qt::PanGesture))
-//        panTriggered(static_cast<QPanGesture *>(pan));
-//    if (QGesture *pinch = event->gesture(Qt::PinchGesture))
-//        pinchTriggered(static_cast<QPinchGesture *>(pinch));
-    return true;
-}
-
-
-bool eWallet::event(QEvent *event)
-{
-    if (event->type() == QEvent::Gesture) {
-    	qDebug () << "GESTURE";
-
-    	if (!isAskPassword) {
-    		return gestureEvent(static_cast<QGestureEvent*>(event));
-    	}
-    }
-    return QWidget::event(event);
-}
+////void eWallet::swipeTriggered(QSwipeGesture *gesture) {
+////	if (gesture->state() == Qt::GestureFinished) {
+////		if (gesture->horizontalDirection() == QSwipeGesture::Left
+////			|| gesture->verticalDirection() == QSwipeGesture::Up)
+////			isShowGroups = (isShowGroups + 1) % 2 + 1;
+////		else
+////			isShowGroups = (isShowGroups + 1) % 2 + 1;
+////		showInfo(false);
+////	}
+////}
+//
+//bool eWallet::gestureEvent(QGestureEvent *event) {
+//    if (QGesture *swipe = event->gesture(Qt::SwipeGesture))
+//    	changeMode();
+//
+////        swipeTriggered(static_cast<QSwipeGesture *>(swipe));
+////    else if (QGesture *pan = event->gesture(Qt::PanGesture))
+////        panTriggered(static_cast<QPanGesture *>(pan));
+////    if (QGesture *pinch = event->gesture(Qt::PinchGesture))
+////        pinchTriggered(static_cast<QPinchGesture *>(pinch));
+//    return true;
+//}
+//
+//
+//bool eWallet::event(QEvent *event)
+//{
+////	qDebug () << "EVENT " << event->type();
+//    if (event->type() == QEvent::Gesture) {
+//    	qDebug () << "GESTURE";
+//
+//    	if (!isAskPassword) {
+//    		return gestureEvent(static_cast<QGestureEvent*>(event));
+//    	}
+//    }
+//    return QWidget::event(event);
+//}
 
 void eWallet::selectItem(QListWidgetItem * item) {
 	if (isShowGroups == 1) {
@@ -177,8 +212,17 @@ void eWallet::selectItem(QListWidgetItem * item) {
 		}
 
 		QString target = grouplist.at(fnListWidget->currentRow());
-		isShowGroups = 2;
-		showTargets(reset, target);
+		//isShowGroups = 2;
+		//backButton->show();
+		if (extraWindow.isNull()) {
+			extraWindow = new eWallet(target, this, this);
+			//extraWindow->setAttribute(Qt::WA_Maemo5StackedWindow);
+			extraWindow->setAttribute(Qt::WA_DeleteOnClose);
+	        connect(extraWindow, SIGNAL(destroyed(QObject*)),
+	                this, SLOT(extrawindowDestroyed(QObject*)));
+	        extraWindow->show();
+		}
+		//showTargets(reset, target);
 	}
 	else {
 		if (fnListWidget->currentItem() != item) {
@@ -190,22 +234,7 @@ void eWallet::selectItem(QListWidgetItem * item) {
 }
 
 void eWallet::selectDItem(QListWidgetItem * item) {
-	if (isShowGroups == 1) {
-		if (fnListWidget->currentItem() != item) {
-			fnListWidget->setCurrentItem(item);
-		}
-
-		QString target = grouplist.at(fnListWidget->currentRow());
-		isShowGroups = 2;
-		showTargets(reset, target);
-	}
-	else {
-		if (fnListWidget->currentItem() != item) {
-			fnListWidget->setCurrentItem(item);
-		}
-		Target * target = list.at(fnListWidget->currentRow());
-		editTarget(target);
-	}
+		selectItem(item);
 }
 
 void eWallet::listenInactivity(QString s) {
@@ -230,13 +259,16 @@ void eWallet::listenInactivity(QString s) {
 			detailWindowEdit = 0;
 	    }
 
+	    if (!extraWindow.isNull()) {
+	    	extraWindow->close();
+			delete extraWindow;
+			extraWindow = 0;
+	    }
+
 	}
 	else {
 		if (s == QString("on") && !::dbManager->isReady ()) {
 			askPassword ();
-//			if (::dbManager->isReady ()) {
-//				showList ();
-//			}
 		}
 	}
 }
@@ -339,13 +371,25 @@ bool eWallet::openDataBase (QString pas)
 	}
 	else {
 		showList ();
+
+		if (isShowGroups == 0) {
+			grouplist.clear ();
+			grouplist = ::dbManager->getGroups ();
+
+			if (grouplist.size() > 1)
+				isShowGroups = 1;
+			else
+				isShowGroups = 2;
+		}
+
+		showInfo (true);
 	}
 	return res;
 }
 
 eWallet::~eWallet ()
 {
-	delete ::dbManager;
+	//delete ::dbManager;
 }
 /*
  * TYPES
@@ -361,6 +405,9 @@ void eWallet::loadTypesAndFields () {
 	  QFile file(":/resources/types.txt");
 	  QString line;
 
+	  types = new QList<QString>;
+	  fieldsByType = new QList<QList<TargetField>*>;
+
 	  if ( file.open(QIODevice::Text | QIODevice::ReadOnly) ) {
 	    // file opened successfully
 	    QTextStream t(&file);        // use a text stream
@@ -377,12 +424,12 @@ void eWallet::loadTypesAndFields () {
 	    		  if (p >= 0) {
 	    			  // TODO
 	    			  QChar imageType = line.at(p + 1);
-					  this->types.append(line.mid(0, p).trimmed());
+					  this->types->append(line.mid(0, p).trimmed());
 	    		  }
 	    		  else {
-					  this->types.append(line);
+					  this->types->append(line);
 	    		  }
-	    		  this->fieldsByType.append (new QList<TargetField>);
+	    		  this->fieldsByType->append (new QList<TargetField>);
 				  //qDebug () << " new type "<< line << " " << this->types.length();
 	    	  }
 	    	  else {
@@ -412,10 +459,10 @@ void eWallet::loadTypesAndFields () {
 						  default:
 			    			  type = TYPE_STRING;
 						}
-	    			  this->fieldsByType [this->types.length() - 1]->append(TargetField (line.mid(0, p).trimmed(), type, true, i));
+	    			  this->fieldsByType->at(this->types->length() - 1)->append(TargetField (line.mid(0, p).trimmed(), type, true, i));
 	    		  }
 	    		  else {
-	    			  this->fieldsByType [this->types.length() - 1]->append(TargetField (line, TYPE_STRING, true, i));
+	    			  this->fieldsByType->at(this->types->length() - 1)->append(TargetField (line, TYPE_STRING, true, i));
 	    		  }
 				  //qDebug () << " new field "<< line << " " << this->types.length();
 	    	  }
@@ -436,22 +483,21 @@ void eWallet::keyPressEvent(QKeyEvent* event) {
 	
 	if (!isAskPassword) {
 		if (searchField->isHidden()) {
-			cancelSearch->show ();
-			searchField->show ();
-			hideSearch->show ();
-			searchField->setFocus();
-
-			QCoreApplication::sendEvent (searchField, event);
-			event->accept();
-		}
-		else {
-//			if (event->key () == Qt::Key_Up) {
-//				cancelSearch->hide ();
-//				searchField->hide ();
-//				hideSearch->hide ();
+//			if (event->key () == Qt::Key_Left || event->key () == Qt::Key_Right ) {
+//				changeMode();
 //				event->accept();
 //			}
-//			else
+//			else {
+				cancelSearch->show ();
+				searchField->show ();
+				hideSearch->show ();
+				searchField->setFocus();
+
+				QCoreApplication::sendEvent (searchField, event);
+				event->accept();
+//			}
+		}
+		else {
 				QWidget::keyPressEvent(event);//event->accept();
 		}
 	}
@@ -468,6 +514,12 @@ bool sortTargetsASC (const Target * f, const Target * g) {
 bool sortTargetsDES (const Target * f, const Target * g) {
 	return f->name.toLower() > g->name.toLower();
 }
+bool sortStringASC (const QString f, const QString g) {
+	return f.toLower() < g.toLower();
+}
+bool sortStringDES (const QString f, const QString g) {
+	return f.toLower() > g.toLower();
+}
 
 QPixmap eWallet::getImage (Target * target) {
 	QPixmap image;
@@ -503,10 +555,10 @@ void eWallet::showGroups(bool reset)
 		grouplist = ::dbManager->getGroups ();
 	}
 
-//	if (ascSort)
-//		qSort (grouplist.begin(),grouplist.end(),sortTargetsASC);
-//	else
-//		qSort (grouplist.begin(),grouplist.end(),sortTargetsDES);
+	if (ascSort)
+		qSort (grouplist.begin(),grouplist.end(),sortStringASC);
+	else
+		qSort (grouplist.begin(),grouplist.end(),sortStringDES);
 
 	//fnListWidget->setIconSize (QSize (SMALL_WIDTH, SMALL_HEIGH));
 	//fnListWidget->setContentsMargins(10, 1, 0, 1);
@@ -527,23 +579,12 @@ void eWallet::showGroups(bool reset)
 }
 
 void eWallet::showInfo(bool reset) {
-	if (isShowGroups == 0) {
-		if (reset) {
-			grouplist.clear ();
-			grouplist = ::dbManager->getGroups ();
-		}
-
-		if (grouplist.size() > 1)
-			isShowGroups = 1;
-		else
-			isShowGroups = 2;
-	}
-
 	if (isShowGroups == 1) {
+		//backButton->hide();
 		showGroups(reset);
 	}
 	else {
-		showTargets(reset, "");
+		showTargets(reset, currentGroup);
 	}
 }
 
@@ -602,7 +643,7 @@ void eWallet::createMenu()
 		menuBar()->addAction("Invert Sort", this, SLOT(sort()));
 		menuBar()->addAction("Import", this, SLOT(import()));
 		menuBar()->addAction("Export", this, SLOT(exportData()));
-		menuBar()->addAction("Change View", this, SLOT(changeMode()));
+		//menuBar()->addAction("Change View", this, SLOT(changeMode()));
 		menuBar()->addAction("Exit", QApplication::instance(), SLOT(quit()));
 	}
 }
@@ -628,28 +669,32 @@ bool eWallet::__insertTarget(Target* target)
 bool eWallet::_insertTarget(Target* target)
 {
 	if (__insertTarget(target)) {
+		if (isShowGroups == 2) {
+			list.append(target);
 
-		list.append(target);
+	//		if (ascSort)
+	//			qSort (list.begin(),list.end(),sortTargetsASC);
+	//		else
+	//			qSort (list.begin(),list.end(),sortTargetsDES);
 
-//		if (ascSort)
-//			qSort (list.begin(),list.end(),sortTargetsASC);
-//		else
-//			qSort (list.begin(),list.end(),sortTargetsDES);
+			QListWidgetItem* listitem = new QListWidgetItem(getImage(target), target->name, fnListWidget);
 
-		QListWidgetItem* listitem = new QListWidgetItem(getImage(target), target->name, fnListWidget);
+			int pos = list.indexOf(target);
+			qDebug () << "position of new " << pos << " OF " << list.size ();
 
-		int pos = list.indexOf(target);
-		qDebug () << "position of new " << pos << " OF " << list.size ();
-
-		if (pos < list.size()) {
-			//qDebug () << "insert position of new " << pos << " OF " << list.size ();
-			fnListWidget->insertItem(pos, listitem);
+			if (pos < list.size()) {
+				//qDebug () << "insert position of new " << pos << " OF " << list.size ();
+				fnListWidget->insertItem(pos, listitem);
+			}
+			else {
+				//qDebug () << "append position of new " << pos << " OF " << list.size ();
+				fnListWidget->addItem(listitem);
+			}
+			fnListWidget->setCurrentItem(listitem);
 		}
 		else {
-			//qDebug () << "append position of new " << pos << " OF " << list.size ();
-			fnListWidget->addItem(listitem);
+			showGroups(true);
 		}
-		fnListWidget->setCurrentItem(listitem);
 		return true;
 	}
 	return false;
@@ -669,19 +714,20 @@ bool eWallet::_deleteTarget(Target* target)
 	delete messageBox;
 	messageBox = 0;
 
-
-	int i = list.indexOf(target);
-	qDebug () << "DELETE ON " << i;
 	if (::dbManager->deleteTarget(target)) {
-		qDebug () << "trying to remove " << i;
-		list.removeAt(i);
+		if (isShowGroups == 2) {
+			int i = list.indexOf(target);
+			qDebug () << "DELETE ON " << i;
+			qDebug () << "trying to remove " << i;
+			list.removeAt(i);
 
-		qDebug () << "trying to takeItem " << i;
-		fnListWidget->takeItem(i); //oveItem (row);
+			qDebug () << "trying to takeItem " << i;
+			fnListWidget->takeItem(i); //oveItem (row);
+			qDebug () << "delete " << i;
+		}
 //		target->freeFieldList();
 //		target->freeResources();
 //		delete target;
-		qDebug () << "delete " << i;
 		delete target;
 		return true;
 	}
@@ -689,7 +735,6 @@ bool eWallet::_deleteTarget(Target* target)
 }
 bool eWallet::_updateTarget(Target* target)
 {
-	int i = list.indexOf(target);
 	//qDebug () << "UPDATE ON " << i;
 
 	if (::dbManager->updateTarget(target)) {
@@ -697,9 +742,14 @@ bool eWallet::_updateTarget(Target* target)
 		
 		target->freeFieldList();
 
-		QListWidgetItem* listitem = fnListWidget->item (i);
-		listitem->setText(target->name);
-		//((QFNListItem*)fnListWidget->currentItem())->setText (target->name);
+		if (isShowGroups == 2) {
+			int i = list.indexOf(target);
+			QListWidgetItem* listitem = fnListWidget->item (i);
+			listitem->setText(target->name);
+		}
+		else {
+			showGroups(true);
+		}
 		return true;
 	}
 	return false;
@@ -707,11 +757,13 @@ bool eWallet::_updateTarget(Target* target)
 
 bool eWallet::_updateTargetPicture(Target* target)
 {
-	int i = list.indexOf(target);
 	//qDebug () << "UPDATE ON " << i;
 	if (::dbManager->updateTargetPicture(target)) {
-		QListWidgetItem* listitem = fnListWidget->item (i);
-		listitem->setIcon(getImage(target));
+		if (isShowGroups == 2) {
+			int i = list.indexOf(target);
+			QListWidgetItem* listitem = fnListWidget->item (i);
+			listitem->setIcon(getImage(target));
+		}
 		return true;
 	}
 	return false;
@@ -730,15 +782,23 @@ void eWallet::deleteTarget(Target * target) {
 	}
 }
 
+void eWallet::extrawindowDestroyed(QObject* obj) {
+    disconnect(obj, SIGNAL(destroyed(QObject*)),
+               this, SLOT(windowDestroyed(QObject*)));
+
+	delete extraWindow;
+	extraWindow = 0;
+
+	qDebug () << "WINDOW DESTROYED YES";
+
+	showGroups (true);
+}
+
 void eWallet::windowDestroyed(QObject* obj)
 {
     disconnect(obj, SIGNAL(destroyed(QObject*)),
                this, SLOT(windowDestroyed(QObject*)));
 
-//    if (currentTarget != NULL) {
-//    	currentTarget->freeFieldList();
-//    }
-
     if (obj == detailWindow.data()) {
 		delete detailWindow;
 		detailWindow = 0;
@@ -751,27 +811,20 @@ void eWallet::windowDestroyed(QObject* obj)
 }
 
 void eWallet::viewTarget(Target * rent) {
-	//qDebug()<<"view ";
-
-	//row = fnListWidget->findRow(rent);
-
-	//currentTarget = rent;
 
 	dbManager->getFields(rent);
 
 	if (detailWindow.isNull()) {
-		detailWindow = new DetailWindow(rent, false, false, this, this);
+		detailWindow = new DetailWindow(rent, "", false, false, this, this);
 
 		connect(detailWindow, SIGNAL(editTarget(Target*)),
                       this, SLOT(editTarget(Target*)));
 		connect(detailWindow, SIGNAL(newTarget()),
                       this, SLOT(newTarget()));
-//#ifdef Q_WS_MAEMO_5
-//#endif
         detailWindow->setAttribute(Qt::WA_DeleteOnClose);
         connect(detailWindow, SIGNAL(destroyed(QObject*)),
                 this, SLOT(windowDestroyed(QObject*)));
-		detailWindow->setAttribute(Qt::WA_Maemo5StackedWindow);
+		//detailWindow->setAttribute(Qt::WA_Maemo5StackedWindow);
 	    detailWindow->show(); //owMaximized();
 	}
 }
@@ -779,21 +832,15 @@ void eWallet::viewTarget(Target * rent) {
 void eWallet::editTarget(Target * rent) {
 	//qDebug()<<"edit ";
 
-	//row = fnListWidget->findRow(rent);
-
 	dbManager->getFields(rent);
 
 	if (detailWindowEdit.isNull()) {
-		detailWindowEdit = new DetailWindow(rent, false, true, this, this);
-//#ifdef Q_WS_MAEMO_5
-		detailWindowEdit->setAttribute(Qt::WA_Maemo5StackedWindow);
-//#endif
-		//detailWindowEdit->showMaximized();
+		detailWindowEdit = new DetailWindow(rent, "", false, true, this, this);
+		//detailWindowEdit->setAttribute(Qt::WA_Maemo5StackedWindow);
         detailWindowEdit->setAttribute(Qt::WA_DeleteOnClose);
         connect(detailWindowEdit, SIGNAL(destroyed(QObject*)),
                 this, SLOT(windowDestroyed(QObject*)));
         detailWindowEdit->show();
-		//detailWindow->exec();
 	}
 }
 
@@ -908,7 +955,7 @@ void eWallet::import() {
 		    // Close the file
 		    file.close();
 
-		    showTargets (true, "");
+		    showInfo (true);
 		  }
 	}
 	this->setAttribute(Qt::WA_Maemo5ShowProgressIndicator, false);
@@ -918,16 +965,12 @@ void eWallet::newTarget() {
 	//qDebug()<<"new ";
 
 	if (detailWindowEdit.isNull()) {
-		detailWindowEdit = new DetailWindow(NULL, false, true, this, this);
-//#ifdef Q_WS_MAEMO_5
-		detailWindowEdit->setAttribute(Qt::WA_Maemo5StackedWindow);
-//#endif
-		//detailWindowEdit->showMaximized();
+		detailWindowEdit = new DetailWindow(NULL, currentGroup, false, true, this, this);
+		//detailWindowEdit->setAttribute(Qt::WA_Maemo5StackedWindow);
         detailWindowEdit->setAttribute(Qt::WA_DeleteOnClose);
         connect(detailWindowEdit, SIGNAL(destroyed(QObject*)),
                 this, SLOT(windowDestroyed(QObject*)));
         detailWindowEdit->show();
-		//detailWindow->exec();
 	}
 }
 
@@ -1003,19 +1046,14 @@ void eWallet::_newLikeTarget() {
 		dbManager->getFields(target);
 
 		if (detailWindowEdit.isNull()) {
-			detailWindowEdit = new DetailWindow(target, true, true, this, this);
-	//#ifdef Q_WS_MAEMO_5
-			detailWindowEdit->setAttribute(Qt::WA_Maemo5StackedWindow);
-	//#endif
-			//detailWindowEdit->showMaximized();
+			detailWindowEdit = new DetailWindow(target, currentGroup, true, true, this, this);
+			//detailWindowEdit->setAttribute(Qt::WA_Maemo5StackedWindow);
 	        detailWindowEdit->setAttribute(Qt::WA_DeleteOnClose);
 	        connect(detailWindowEdit, SIGNAL(destroyed(QObject*)),
 	                this, SLOT(windowDestroyed(QObject*)));
 	        detailWindowEdit->show();
-			//detailWindow->exec();
 		}
 	}
-	//editTarget(((QFNListItem*)fnListWidget->currentItem())->getSource());
 }
 
 void eWallet::_editcTarget() {
@@ -1023,28 +1061,23 @@ void eWallet::_editcTarget() {
 		Target * target = list.at(fnListWidget->currentRow());
 		editTarget(target);
 	}
-	//editTarget(((QFNListItem*)fnListWidget->currentItem())->getSource());
 }
 void eWallet::_deletecTarget() {
 	if (fnListWidget->currentRow() >= 0) {
 		Target * target = list.at(fnListWidget->currentRow());
 		deleteTarget(target);
 	}
-	//deleteTarget(((QFNListItem*)fnListWidget->currentItem())->getSource());
 }
 void eWallet::_viewcTarget() {
 	if (fnListWidget->currentRow() >= 0) {
 		Target * target = list.at(fnListWidget->currentRow());
 		viewTarget(target);
 	}
-	//viewTarget(((QFNListItem*)fnListWidget->currentItem())->getSource());
 }
 
-//eWallet closeEvent function:
 void eWallet::closeEvent(QCloseEvent *event){
 	//qDebug () << "close Event";
-        //saveSettings();
-        event->accept();
+	event->accept();
 }
 
 void eWallet::askPassword () {
