@@ -20,6 +20,7 @@ class eWallet: public QMainWindow
 
 public:
 	eWallet (QWidget *parent = 0);
+	eWallet (QString group, eWallet *_parent, QWidget *parent = 0);
 	~eWallet ();
 
 	bool openDataBase (QString pas);
@@ -30,8 +31,8 @@ public:
 	bool _insertTarget(Target* target);
 	bool __insertTarget(Target* target);
 	
-	QList<QString> types;
-	QList<QList<TargetField>*> fieldsByType;
+	QList<QString> * types;
+	QList<QList<TargetField>*> * fieldsByType;
 
 public slots:
 	void newTarget();
@@ -47,9 +48,9 @@ public slots:
 	void changeMode ();
 
 private:
-	bool event (QEvent *event);
-	void swipeTriggered (QSwipeGesture *gesture);
-	bool gestureEvent (QGestureEvent *event);
+//	bool event (QEvent *event);
+////	void swipeTriggered (QSwipeGesture *gesture);
+//	bool gestureEvent (QGestureEvent *event);
 
 	void showList ();
 	void keyPressEvent(QKeyEvent*);
@@ -65,9 +66,11 @@ private:
 private slots:
 	void orientationChanged(int);
     void windowDestroyed(QObject* obj = 0);
+    void extrawindowDestroyed(QObject* obj = 0);
     void sort ();
     void _newLikeTarget ();
 	void _editcTarget();
+	void _clickBack();
 	void _deletecTarget();
 	void _viewcTarget();
 	void lockWallet ();
@@ -93,10 +96,12 @@ private:
 	QPushButton * cancelSearch;
 	QPushButton * hideSearch;
 	QLineEdit * searchField;
+	//QPushButton * backButton;
 
 	QPointer<LoginDialog> loginDialogDlg;
 	QPointer<DetailWindow> detailWindow;
 	QPointer<DetailWindow> detailWindowEdit;
+	QPointer<eWallet> extraWindow;
 	QWidget* centralWidget;
 	QPointer <QMessageBox> messageBox;
 	bool opendb;
@@ -104,7 +109,7 @@ private:
 	bool ascSort;
 	int isShowGroups;
 	QString currentFilter;
-
+	QString currentGroup;
 };
 
 
